@@ -29,7 +29,6 @@
 
 //---------------------------------------------------------------------------
 #include "MediaInfo/Setup.h"
-#include <bitset>
 //---------------------------------------------------------------------------
 
 //---------------------------------------------------------------------------
@@ -39,6 +38,7 @@
 //---------------------------------------------------------------------------
 #include "MediaInfo/Audio/File_Adm.h"
 #include "ThirdParty/tfsxml/tfsxml.h"
+#include <bitset>
 using namespace ZenLib;
 using namespace std;
 //---------------------------------------------------------------------------
@@ -46,6 +46,8 @@ using namespace std;
 namespace MediaInfoLib
 {
 
+#define IncoherencyMessage "Incoherency between enums and message strings"
+    
 //---------------------------------------------------------------------------
 static float32 TimeCodeToFloat(string v)
 {
@@ -152,6 +154,16 @@ static bool IsHexaDigit(char Value)
         || (Value >= 'a' && Value <= 'f');
 }
 
+static bool IsHexaDigit(const string& Value, size_t pos, size_t len)
+{
+    len += pos;
+    for (; pos < len; pos++) {
+        if (!IsHexaDigit(Value[pos]))
+            return false;
+    }
+    return true;
+}
+
 enum flags {
     Version0,
     Version1,
@@ -179,7 +191,7 @@ struct element {
     int                 Elements_Count;
 };
 
-enum items {
+enum item {
     item_audioTrack,
     item_audioProgramme,
     item_audioContent,
@@ -189,10 +201,45 @@ enum items {
     item_audioTrackUID,
     item_audioTrackFormat,
     item_audioStreamFormat,
+    item_audioBlockFormat,
+    item_alternativeValueSet,
     item_Max
 };
 
+struct item_info
+{
+    const char* Name;
+    const char* ID_Begin;
+    enum flags : int8u {
+        Flags_ID_W,
+        Flags_ID_YX,
+        Flags_ID_Z1, // Z width x2
+        Flags_ID_Z2, // Z width x2
+        Flags_Max,
+    };
+    int8u       ID_Flags;
+};
+#define D(_1,_2,_3) {_1,_2,_3}
+#define F(_1) (1 << item_info::Flags_##_1)
+static item_info item_Info[] = {
+    D("TrackIndex", nullptr, 0),
+    D("Programme", "APR", F(ID_W)),
+    D("Content", "ACO", F(ID_W)),
+    D("Object", "AO", F(ID_W)),
+    D("PackFormat", "AP", F(ID_YX)),
+    D("ChannelFormat", "AC", F(ID_YX)),
+    D("TrackUID", "ATU", 0),
+    D("TrackFormat", "AT", F(ID_YX) | F(ID_Z1)),
+    D("StreamFormat", "AS", F(ID_YX)),
+    D("BlockFormat", "AB", F(ID_YX) | F(ID_Z1) | F(ID_Z2)),
+    D("alternativeValueSet", "AVS", F(ID_W) | F(ID_Z2)),
+};
+#undef D
+#undef F
+static_assert(sizeof(item_Info) / sizeof(item_info) == item_Max, IncoherencyMessage);
+
 enum audioTrack_String {
+    audioTrack_audioTrackID,
     audioTrack_Summary,
     audioTrack_String_Max
 };
@@ -209,12 +256,27 @@ enum audioProgramme_String {
     audioProgramme_start,
     audioProgramme_end,
     audioProgramme_typeLabel,
+    audioProgramme_typeDefinition,
+    audioProgramme_typeLink,
+    audioProgramme_typeLanguage,
+    audioProgramme_formatLabel,
+    audioProgramme_formatDefinition,
+    audioProgramme_formatLink,
+    audioProgramme_formatLanguage,
+    audioProgramme_maxDuckingDepth,
     audioProgramme_String_Max
 };
 
 enum audioProgramme_StringVector {
     audioProgramme_audioProgrammeLabel,
     audioProgramme_audioContentIDRef,
+    audioProgramme_loudnessMetadata,
+    audioProgramme_loudnessMetadata_integratedLoudness,
+    audioProgramme_audioProgrammeReferenceScreen,
+    audioProgramme_authoringInformation,
+    audioProgramme_authoringInformation_referenceLayout,
+    audioProgramme_authoringInformation_referenceLayout_audioPackFormatIDRef,
+    audioProgramme_alternativeValueSetIDRef,
     audioProgramme_StringVector_Max
 };
 
@@ -229,7 +291,8 @@ enum audioContent_String {
 enum audioContent_StringVector {
     audioContent_dialogue,
     audioContent_audioContentLabel,
-    audioContent_integratedLoudness,
+    audioContent_loudnessMetadata,
+    audioContent_loudnessMetadata_integratedLoudness,
     audioContent_audioObjectIDRef,
     audioContent_StringVector_Max
 };
@@ -246,6 +309,8 @@ enum audioObject_String {
 enum audioObject_StringVector {
     audioObject_audioPackFormatIDRef,
     audioObject_audioTrackUIDRef,
+    audioObject_audioObjectIDRef,
+    audioObject_audioComplementaryObjectIDRef,
     audioObject_StringVector_Max
 };
 
@@ -338,18 +403,31 @@ static attribute_item audioProgramme_Attributes[] =
     { "audioProgrammeLanguage"          , (1 << Version0) | (1 << Version1) | (1 << Version2) },
     { "start"                           , (1 << Version0) | (1 << Version1) | (1 << Version2) },
     { "end"                             , (1 << Version0) | (1 << Version1) | (1 << Version2) },
+    { "typeLabel"                       , (1 << Version0) },
+    { "typeDefinition"                  , (1 << Version0) },
+    { "typeLink"                        , (1 << Version0) },
+    { "typeLanguage"                    , (1 << Version0) },
+    { "formatLabel"                     , (1 << Version0) },
+    { "formatDefinition"                , (1 << Version0) },
+    { "formatLink"                      , (1 << Version0) },
+    { "formatLanguage"                  , (1 << Version0) },
     { "maxDuckingDepth"                 , (1 << Version0) | (1 << Version1) | (1 << Version2) },
 };
+static_assert(sizeof(audioProgramme_Attributes) / sizeof(attribute_item) == audioProgramme_String_Max, IncoherencyMessage);
 
 static element_item audioProgramme_Elements[] =
 {
     { "audioProgrammeLabel"             ,                                     (1 << Version2) },
     { "audioContentIDRef"               , (1 << Version0) | (1 << Version1) | (1 << Version2) | (1 << Count1) | (1 << Count2) },
     { "loudnessMetadata"                , (1 << Version0) | (1 << Version1) | (1 << Version2) },
+    { "integratedLoudness"              , (1 << Version0) | (1 << Version1) | (1 << Version2) },
     { "audioProgrammeReferenceScreen"   , (1 << Version0) | (1 << Version1) | (1 << Version2) | (1 << Count0) | (1 << Count1) },
     { "authoringInformation"            ,                                     (1 << Version2) | (1 << Count0) | (1 << Count1) },
+    { "referenceLayout"            ,                                          (1 << Version2) | (1 << Count0) | (1 << Count1) },
+    { "audioPackFormatIDRef"            ,                                     (1 << Version2) | (1 << Count0) | (1 << Count1) },
     { "alternativeValueSetIDRef"        ,                                     (1 << Version2) | (1 << Count0) | (1 << Count1) },
 };
+static_assert(sizeof(audioProgramme_Elements) / sizeof(attribute_item) == audioProgramme_StringVector_Max, IncoherencyMessage);
 
 static element audioProgramme_Element =
 {
@@ -392,16 +470,16 @@ struct Items_Struct {
     size_t StringVectors_Size;
 };
 
-static string Apply_Init(File__Analyze& F, const Char* Name, size_t i, const Items_Struct& audioProgramme_List, Ztring Summary) {
+static string Apply_Init(File__Analyze& F, const char* Name, size_t i, const Items_Struct& audioProgramme_List, Ztring Summary) {
     const Item_Struct& audioProgramme = audioProgramme_List.Items[i];
-    string P = Ztring(Name + Ztring::ToZtring(i)).To_UTF8();
+    string P = Name + to_string(i);
     F.Fill(Stream_Audio, 0, P.c_str(), Summary.empty() ? __T("Yes") : Summary);
     F.Fill(Stream_Audio, 0, (P + " Pos").c_str(), i);
     F.Fill_SetOptions(Stream_Audio, 0, (P + " Pos").c_str(), "N NIY");
     return P;
 }
 
-static void Apply_SubStreams(File__Analyze& F, const string& P_And_LinkedTo, const Item_Struct& Source, size_t i, const Items_Struct& Dest) {
+static void Apply_SubStreams(File__Analyze& F, const string& P_And_LinkedTo, Item_Struct& Source, size_t i, Items_Struct& Dest) {
     ZtringList SubstreamPos, SubstreamNum;
     for (size_t j = 0; j < Source.StringVectors[i].size(); j++) {
         const string& ID = Source.StringVectors[i][j];
@@ -413,6 +491,20 @@ static void Apply_SubStreams(File__Analyze& F, const string& P_And_LinkedTo, con
             }
         }
         if (Pos == -1) {
+            auto LinkedTo_Pos = P_And_LinkedTo.find(" LinkedTo_TrackUID_Pos");
+            auto HasTransport = !F.Retrieve_Const(Stream_Audio, 0, "Transport0").empty();
+            if (HasTransport && LinkedTo_Pos != string::npos) { // TODO: better way to avoid common definitions
+                string Message;
+                if (LinkedTo_Pos) {
+                    auto Sub_Pos = P_And_LinkedTo.rfind(' ', LinkedTo_Pos - 1);
+                    if (Sub_Pos != string::npos) {
+                        Message += ":transportTrackFormat:audioTrack:audioTrackUIDRef:\"";
+                        Message += ID;
+                        Message += "\" is referenced but its description is missing";
+                        Source.Errors[Warning].push_back(Message);
+                    }
+                }
+            }
             continue;
         }
         SubstreamPos.push_back(Ztring::ToZtring(Pos));
@@ -428,6 +520,14 @@ static void Apply_SubStreams(File__Analyze& F, const string& P_And_LinkedTo, con
     F.Fill_SetOptions(Stream_Audio, 0, (P_And_LinkedTo + "/String").c_str(), "Y NIN");
 }
 
+
+//***************************************************************************
+// Private class
+//***************************************************************************
+
+static void CheckErrors_Formating(file_adm_private* File_Adm_Private, const string& ID, const item_info& ID_Start, vector<string>& Errors, const char* Sub = nullptr);
+static void CheckErrors_Formating(file_adm_private* File_Adm_Private, Items_Struct& MainItem, const item_info& ID_Start, const char* Sub = nullptr);
+
 class file_adm_private
 {
 public:
@@ -471,6 +571,9 @@ public:
     void audioFormatExtended();
     void frameHeader();
     void transportTrackFormat();
+
+    // Common definitions
+    vector<string> audioChannelFormatIDRefs;
 };
 
 void file_adm_private::parse()
@@ -502,8 +605,8 @@ void file_adm_private::parse()
                 } \
 
     #define ELEMENT_MIDDLE(NAME) \
-                else if (tfsxml_strcmp_charp(b, "typeLabel")) { \
-                    NAME##_Content.Errors[Warning].push_back("Attribute \"" + tfsxml_decode(b) + "\" is out of specs"); \
+                else if (!Items[item_audioProgramme].Items.empty() && &NAME##_Content == &Items[item_audioProgramme].Items.back()) { \
+                    NAME##_Content.Errors[Warning].push_back(":XmlAttributes:\"" + tfsxml_decode(b) + "\" is not part of specs"); \
                 } \
             } \
         if (!tfsxml_enter(&p)) \
@@ -515,8 +618,8 @@ void file_adm_private::parse()
                 } \
 
     #define ELEMENT_END(NAME) \
-                    else if (tfsxml_strcmp_charp(b, "loudnessMetadata") && tfsxml_strcmp_charp(b, "authoringInformation") && tfsxml_strcmp_charp(b, "alternativeValueSetIDRef")) { \
-                        NAME##_Content.Errors[Warning].push_back("Element \"" + tfsxml_decode(b) + "\" is out of specs"); \
+                    else if (!Items[item_audioProgramme].Items.empty() && &NAME##_Content == &Items[item_audioProgramme].Items.back()) { \
+                        NAME##_Content.Errors[Warning].push_back(":XmlElements:\"" + tfsxml_decode(b) + "\" is not part of specs"); \
                     } \
                 } \
             } \
@@ -527,7 +630,13 @@ void file_adm_private::parse()
             NAME##_Content.Strings[NAME##_##ATTR].assign(tfsxml_decode(v)); \
         } \
 
-    #define ATTRIBUTE_I(NAME,ATTR) \
+    #define ATTRIB_ID(NAME,ATTR) \
+        else if (!tfsxml_strcmp_charp(b, #ATTR)) { \
+            CheckErrors_Formating(this, tfsxml_decode(v), item_Info[item_##NAME], *this->Items[item_##NAME].Items.back().Errors, #NAME":"#ATTR); \
+            NAME##_Content.Strings[NAME##_##ATTR].assign(tfsxml_decode(v)); \
+        } \
+
+#define ATTRIBUTE_I(NAME,ATTR) \
         else if (!tfsxml_strcmp_charp(b, #ATTR)) { \
         } \
 
@@ -665,13 +774,21 @@ void file_adm_private::audioFormatExtended()
         if (tfsxml_next(&p, &b))
             break;
         ELEMENT_START(audioProgramme)
-            ATTRIBUTE(audioProgramme, audioProgrammeID)
+            ATTRIB_ID(audioProgramme, audioProgrammeID)
             ATTRIBUTE(audioProgramme, audioProgrammeName)
             ATTRIBUTE(audioProgramme, audioProgrammeLanguage)
             ATTRIBUTE(audioProgramme, start)
             ATTRIBUTE(audioProgramme, end)
+            ATTRIBUTE(audioProgramme, typeLabel)
+            ATTRIBUTE(audioProgramme, typeDefinition)
+            ATTRIBUTE(audioProgramme, typeLink)
+            ATTRIBUTE(audioProgramme, typeLanguage)
+            ATTRIBUTE(audioProgramme, formatLabel)
+            ATTRIBUTE(audioProgramme, formatDefinition)
+            ATTRIBUTE(audioProgramme, formatLink)
+            ATTRIBUTE(audioProgramme, formatLanguage)
+            ATTRIBUTE(audioProgramme, maxDuckingDepth)
         ELEMENT_MIDDLE(audioProgramme)
-            ELEMENT(audioProgramme, audioContentIDRef)
             else if (!tfsxml_strcmp_charp(b, "audioProgrammeLabel")) {
                 string Language;
                 for (;;) {
@@ -688,9 +805,47 @@ void file_adm_private::audioFormatExtended()
                 }
                 audioProgramme_Content.StringVectors[audioProgramme_audioProgrammeLabel].push_back(Value);
             }
+            ELEMENT(audioProgramme, audioContentIDRef)
+            else if (!tfsxml_strcmp_charp(b, "loudnessMetadata")) {
+                if (!tfsxml_enter(&p))
+                {
+                    for (;;) {
+                        if (tfsxml_next(&p, &b))
+                            break;
+                        if (!tfsxml_strcmp_charp(b, "integratedLoudness")) {
+                            tfsxml_value(&p, &b);
+                            audioProgramme_Content.StringVectors[audioProgramme_loudnessMetadata_integratedLoudness].push_back(tfsxml_decode(b));
+                        }
+                    }
+                }
+            }
+            ELEMENT(audioProgramme, audioProgrammeReferenceScreen)
+            else if (!tfsxml_strcmp_charp(b, "authoringInformation")) {
+                if (!tfsxml_enter(&p))
+                {
+                    for (;;) {
+                        if (tfsxml_next(&p, &b))
+                            break;
+                        if (!tfsxml_strcmp_charp(b, "referenceLayout")) {
+                            if (!tfsxml_enter(&p))
+                            {
+                                for (;;) {
+                                    if (tfsxml_next(&p, &b))
+                                        break;
+                                    if (!tfsxml_strcmp_charp(b, "audioPackFormatIDRef")) {
+                                        tfsxml_value(&p, &b);
+                                        audioProgramme_Content.StringVectors[audioProgramme_authoringInformation_referenceLayout_audioPackFormatIDRef].push_back(tfsxml_decode(b));
+                                    }
+                                }
+                            }
+                        }
+                    }
+                }
+            }
+            ELEMENT(audioProgramme, alternativeValueSetIDRef)
         ELEMENT_END(audioProgramme)
         ELEMENT_START(audioContent)
-            ATTRIBUTE(audioContent, audioContentID)
+            ATTRIB_ID(audioContent, audioContentID)
             ATTRIBUTE(audioContent, audioContentName)
             ATTRIBUTE(audioContent, audioContentLanguage)
             ATTRIBUTE(audioContent, typeLabel)
@@ -790,7 +945,7 @@ void file_adm_private::audioFormatExtended()
                 }
                 audioContent_Content.StringVectors[audioContent_audioContentLabel].push_back(Value);
             }
-            if (!tfsxml_strcmp_charp(b, "loudnessMetadata")) {
+            else if (!tfsxml_strcmp_charp(b, "loudnessMetadata")) {
                 if (!tfsxml_enter(&p))
                 {
                     for (;;) {
@@ -798,7 +953,7 @@ void file_adm_private::audioFormatExtended()
                             break;
                         if (!tfsxml_strcmp_charp(b, "integratedLoudness")) {
                             tfsxml_value(&p, &b);
-                            audioContent_Content.StringVectors[audioContent_integratedLoudness].push_back(tfsxml_decode(b));
+                            audioContent_Content.StringVectors[audioContent_loudnessMetadata_integratedLoudness].push_back(tfsxml_decode(b));
                         }
                     }
                 }
@@ -806,7 +961,7 @@ void file_adm_private::audioFormatExtended()
             ELEMENT(audioContent, dialogue)
         ELEMENT_END(audioContent)
         ELEMENT_START(audioObject)
-            ATTRIBUTE(audioObject, audioObjectID)
+            ATTRIB_ID(audioObject, audioObjectID)
             ATTRIBUTE(audioObject, audioObjectName)
             ATTRIBUTE(audioObject, duration)
             ATTRIBUTE(audioObject, startTime)
@@ -814,9 +969,11 @@ void file_adm_private::audioFormatExtended()
         ELEMENT_MIDDLE(audioObject)
             ELEMENT(audioObject, audioPackFormatIDRef)
             ELEMENT(audioObject, audioTrackUIDRef)
+            ELEMENT(audioObject, audioObjectIDRef)
+            ELEMENT(audioObject, audioComplementaryObjectIDRef)
         ELEMENT_END(audioObject)
         ELEMENT_START(audioPackFormat)
-            ATTRIBUTE(audioPackFormat, audioPackFormatID)
+            ATTRIB_ID(audioPackFormat, audioPackFormatID)
             ATTRIBUTE(audioPackFormat, audioPackFormatName)
             ATTRIBUTE(audioPackFormat, typeDefinition)
             ATTRIBUTE(audioPackFormat, typeLabel)
@@ -824,12 +981,21 @@ void file_adm_private::audioFormatExtended()
             ELEMENT(audioPackFormat, audioChannelFormatIDRef)
         ELEMENT_END(audioPackFormat)
         ELEMENT_START(audioChannelFormat)
-            ATTRIBUTE(audioChannelFormat, audioChannelFormatID)
+            ATTRIB_ID(audioChannelFormat, audioChannelFormatID)
             ATTRIBUTE(audioChannelFormat, audioChannelFormatName)
             ATTRIBUTE(audioChannelFormat, typeDefinition)
             ATTRIBUTE(audioChannelFormat, typeLabel)
         ELEMENT_MIDDLE(audioChannelFormat)
             else if (!tfsxml_strcmp_charp(b, "audioBlockFormat")) {
+                for (;;) {
+                    if (tfsxml_attr(&p, &b, &v))
+                        break;
+                    if (false) {
+                    }
+                    else if (!tfsxml_strcmp_charp(b, "audioBlockFormatID")) {
+                        CheckErrors_Formating(this, tfsxml_decode(v), item_Info[item_audioBlockFormat], *this->Items[item_audioChannelFormat].Items.back().Errors, "audioBlockFormat:audioBlockFormatID");
+                    }
+                }
                 if (!tfsxml_enter(&p))
                 {
                     for (;;) {
@@ -870,7 +1036,7 @@ void file_adm_private::audioFormatExtended()
             ELEMENT(audioTrackUID, audioTrackFormatIDRef)
         ELEMENT_END(audioTrackUID)
         ELEMENT_START(audioTrackFormat)
-            ATTRIBUTE(audioTrackFormat, audioTrackFormatID)
+            ATTRIB_ID(audioTrackFormat, audioTrackFormatID)
             ATTRIBUTE(audioTrackFormat, audioTrackFormatName)
             ATTRIBUTE(audioTrackFormat, formatDefinition)
             ATTRIBUTE(audioTrackFormat, typeDefinition)
@@ -879,7 +1045,7 @@ void file_adm_private::audioFormatExtended()
             ELEMENT(audioTrackFormat, audioStreamFormatIDRef)
         ELEMENT_END(audioTrackFormat)
         ELEMENT_START(audioStreamFormat)
-            ATTRIBUTE(audioStreamFormat, audioStreamFormatID)
+            ATTRIB_ID(audioStreamFormat, audioStreamFormatID)
             ATTRIBUTE(audioStreamFormat, audioStreamFormatName)
             ATTRIBUTE(audioStreamFormat, formatDefinition)
             ATTRIBUTE(audioStreamFormat, formatLabel)
@@ -945,6 +1111,126 @@ void file_adm_private::transportTrackFormat()
     }
 }
 
+//---------------------------------------------------------------------------
+static void FillErrors(file_adm_private* File_Adm_Private, const item Item, size_t i, const char* Name, vector<string>* Errors_Field, vector<string>* Errors_Value, bool WarningError)
+{
+    for (size_t k = 0; k < error_Type_Max; k++) {
+        if (!File_Adm_Private->Items[Item].Items[i].Errors[k].empty()) {
+            for (size_t j = 0; j < File_Adm_Private->Items[Item].Items[i].Errors[k].size(); j++) {
+                string Field = Name;
+                string Value = File_Adm_Private->Items[Item].Items[i].Errors[k][j];
+                if (!Value.empty() && Value[0] == '!') {
+                    auto End = Value.find('!', 1);
+                    if (End != string::npos)
+                    {
+                        Field.insert(0, Value.substr(1, End - 1) + ' ');
+                        Value.erase(0, End + 1);
+                    }
+                }
+                if (!Value.empty() && Value[0] == ':') {
+                    Field.clear();
+                    auto End = Value.rfind(':');
+                    if (End)
+                    {
+                        if (!Field.empty())
+                            Field += ' ';
+                        Field += Value.substr(1, End - 1);
+                        Value.erase(0, End + 1);
+                        for (;;)
+                        {
+                            auto Next = Field.find(':');
+                            if (Next == string::npos)
+                                break;
+                            Field[Next] = ' ';
+                        }
+                    }
+                }
+                Errors_Field[WarningError ? Error : k].push_back(Field);
+                Errors_Value[WarningError ? Error : k].push_back(Value);
+            }
+        }
+    }
+}
+
+//---------------------------------------------------------------------------
+static void CheckErrors_Formating(file_adm_private* File_Adm_Private, const string& ID, const item_info& ID_Start, vector<string>& Errors, const char* Sub)
+{
+    auto BeginSize = strlen(ID_Start.ID_Begin);
+    bitset<item_info::Flags_Max> Flags(ID_Start.ID_Flags);
+    auto MiddleSize = Flags[item_info::Flags_ID_YX] ? 8 : (Flags[item_info::Flags_ID_W] ? 4 : 0);
+    static const int end_size []  = {0, 2, 4, 8};
+    auto EndSize = end_size[Flags[item_info::Flags_ID_Z1] + Flags[item_info::Flags_ID_Z2] * 2];
+    if (!MiddleSize && !EndSize && ID.size() > BeginSize) {
+        EndSize = ID.size() - BeginSize - 1;
+    }
+    auto TotalMiddleSize = MiddleSize ? (1 + MiddleSize) : 0;
+    auto TotalEndSize = EndSize ? (1 + EndSize) : 0;
+    if (ID.size() != BeginSize + TotalMiddleSize + TotalEndSize
+        || ID.compare(0, BeginSize, ID_Start.ID_Begin, 0, BeginSize)
+        || ID[BeginSize] != '_'
+        || !IsHexaDigit(ID, BeginSize + 1, MiddleSize)
+        || (EndSize && ID[BeginSize + TotalMiddleSize] != '_')
+        || !IsHexaDigit(ID, BeginSize + TotalMiddleSize + 1, EndSize)
+        ) {
+        string Middle;
+        if (Flags[item_info::Flags_ID_YX]) {
+            Middle.append(4, 'y');
+            Middle.append(4, 'x');
+        }
+        else if (Flags[item_info::Flags_ID_W]) {
+            Middle.append(4, 'w');
+        }
+        string End;
+        if (EndSize) {
+            End.append(EndSize, 'z');
+        }
+        string Message = (Sub ? (':' + string(Sub) + ':') : string()) + '"' + ID + '"';
+        Message += " is not a valid form (";
+        if (BeginSize) {
+            Message.append(ID_Start.ID_Begin, BeginSize);
+        }
+        Message += '_';
+        if (!Middle.empty()) {
+            Message += Middle;
+        }
+        if (!Middle.empty() && !End.empty()) {
+            Message += '_';
+        }
+        if (!End.empty()) {
+            Message += End;
+        }
+        Message += " form, ";
+        if (!Middle.empty()) {
+            Message += Middle;
+        }
+        if (!Middle.empty() && !End.empty()) {
+            Message += " and ";
+        }
+        if (!End.empty()) {
+            Message += End;
+        }
+        Message += " being hexadecimal digits)";
+        Errors.push_back(Message);
+    }
+}
+
+//---------------------------------------------------------------------------
+static void CheckErrors_Formating(file_adm_private* File_Adm_Private, Items_Struct& MainItem, const item_info& ID_Start, const char* Sub)
+{
+    if (!ID_Start.ID_Begin)
+        return;
+    for (size_t i = 0; i < MainItem.Items.size(); i++) {
+        CheckErrors_Formating(File_Adm_Private, MainItem.Items[i].Strings[audioProgramme_audioProgrammeID], ID_Start, *MainItem.Items[i].Errors, Sub);
+    }
+}
+
+static void CheckErrors(file_adm_private* File_Adm_Private)
+{
+    for (size_t t=0; t<item_Max; t++) {
+        //CheckErrors_Formating(File_Adm_Private, File_Adm_Private->Items[t], item_Info[t]);
+    }
+}
+
 //***************************************************************************
 // Constructor/Destructor
 //***************************************************************************
@@ -979,16 +1265,21 @@ void File_Adm::Streams_Fill()
             File_Adm_Private->Items[item_audioTrack].Items.erase(File_Adm_Private->Items[item_audioTrack].Items.begin());
     }
 
-    #define FILL_COUNT(NAME,FIELD) \
+    #define FILL_COUNT(NAME) \
         if (!File_Adm_Private->Items[item_##NAME].Items.empty()) \
-            Fill(Stream_Audio, 0, "NumberOf" FIELD "s", File_Adm_Private->Items[item_##NAME].Items.size());
+            Fill(Stream_Audio, 0, ("NumberOf" + string(item_Info[item_##NAME].Name) + 's').c_str(), File_Adm_Private->Items[item_##NAME].Items.size());
 
-    #define FILL_START(NAME,ATTRIBUTE,FIELD) \
+    #define FILL_START(NAME,ATTRIBUTE) \
         for (size_t i = 0; i < File_Adm_Private->Items[item_##NAME].Items.size(); i++) { \
             Ztring Summary = Ztring().From_UTF8(File_Adm_Private->Items[item_##NAME].Items[i].Strings[NAME##_##ATTRIBUTE]); \
-            string P = Apply_Init(*this, __T(FIELD), i, File_Adm_Private->Items[item_##NAME], Summary); \
+            string P = Apply_Init(*this, item_Info[item_##NAME].Name, i, File_Adm_Private->Items[item_##NAME], Summary); \
 
-    #define FILL_A(NAME,ATTRIBUTE,FIELD) \
+    #define FILL_START_SUB(NAME,ATTRIBUTE,FIELD) \
+        for (size_t i = 0; i < File_Adm_Private->Items[item_##NAME].Items.size(); i++) { \
+            Ztring Summary = Ztring().From_UTF8(File_Adm_Private->Items[item_##NAME].Items[i].Strings[NAME##_##ATTRIBUTE]); \
+            string P = Apply_Init(*this, FIELD, i, File_Adm_Private->Items[item_##NAME], Summary); \
+
+#define FILL_A(NAME,ATTRIBUTE,FIELD) \
         Fill(Stream_Audio, StreamPos_Last, (P + ' ' + FIELD).c_str(), File_Adm_Private->Items[item_##NAME].Items[i].Strings[NAME##_##ATTRIBUTE].c_str(), Unlimited, true, true); \
 
     #define FILL_E(NAME,ATTRIBUTE,FIELD) \
@@ -1066,16 +1357,16 @@ void File_Adm::Streams_Fill()
     for (size_t i = 0; i < item_Max; i++)
         TotalCount += File_Adm_Private->Items[i].Items.size();
     bool Full = TotalCount < 0x1000 ? true : false;
-    FILL_COUNT(audioProgramme, "Programme");
-    FILL_COUNT(audioContent, "Content");
-    FILL_COUNT(audioObject, "Object");
-    FILL_COUNT(audioPackFormat, "PackFormat");
-    FILL_COUNT(audioChannelFormat, "ChannelFormat");
+    FILL_COUNT(audioProgramme);
+    FILL_COUNT(audioContent);
+    FILL_COUNT(audioObject);
+    FILL_COUNT(audioPackFormat);
+    FILL_COUNT(audioChannelFormat);
     if (Full)
     {
-        FILL_COUNT(audioTrackUID, "TrackUID");
-        FILL_COUNT(audioTrackFormat, "TrackFormat");
-        FILL_COUNT(audioStreamFormat, "StreamFormat");
+        FILL_COUNT(audioTrackUID);
+        FILL_COUNT(audioTrackFormat);
+        FILL_COUNT(audioStreamFormat);
     }
     #if MEDIAINFO_ADVANCED
     vector<string> Errors_Field[error_Type_Max];
@@ -1084,7 +1375,15 @@ void File_Adm::Streams_Fill()
     bool WarningError=MediaInfoLib::Config.WarningError();
     #endif
 
-    FILL_START(audioProgramme, audioProgrammeName, "Programme")
+    // Common definitions
+    for (size_t i = 0; i < File_Adm_Private->Items[item_audioPackFormat].Items.size(); i++) {
+        const Item_Struct& Source = File_Adm_Private->Items[item_audioPackFormat].Items[i];
+        for (size_t j = 0; j < Source.StringVectors[audioPackFormat_audioChannelFormatIDRef].size(); j++) {
+
+        }
+    }
+
+    FILL_START(audioProgramme, audioProgrammeName)
         if (Full)
             FILL_A(audioProgramme, audioProgrammeID, "ID");
         FILL_A(audioProgramme, audioProgrammeName, "Title");
@@ -1092,7 +1391,9 @@ void File_Adm::Streams_Fill()
         FILL_A(audioProgramme, audioProgrammeLanguage, "Language");
         FILL_A(audioProgramme, start, "Start");
         FILL_A(audioProgramme, end, "End");
+        FILL_E(audioProgramme, loudnessMetadata_integratedLoudness, "IntegratedLoudness");
         LINK(audioProgramme, "Content", audioContentIDRef, audioContent);
+        LINK(audioProgramme, "PackFormat", authoringInformation_referenceLayout_audioPackFormatIDRef, audioPackFormat);
         const Ztring& Label = Retrieve_Const(StreamKind_Last, StreamPos_Last, (P + " Label").c_str());
         if (!Label.empty()) {
             Summary += __T(' ');
@@ -1102,31 +1403,7 @@ void File_Adm::Streams_Fill()
             Fill(StreamKind_Last, StreamPos_Last, P.c_str(), Summary, true);
         }
 
-        // Errors
-        const string& audioProgrammeID = File_Adm_Private->Items[item_audioProgramme].Items[i].Strings[audioProgramme_audioProgrammeID];
-        if (audioProgrammeID.size() != 8
-            || audioProgrammeID[0] != 'A'
-            || audioProgrammeID[1] != 'P'
-            || audioProgrammeID[2] != 'R'
-            || audioProgrammeID[3] != '_'
-            || !IsHexaDigit(audioProgrammeID[4])
-            || !IsHexaDigit(audioProgrammeID[5])
-            || !IsHexaDigit(audioProgrammeID[6])
-            || !IsHexaDigit(audioProgrammeID[7])
-            ) {
-            File_Adm_Private->Items[item_audioProgramme].Items[i].Errors->push_back(audioProgrammeID + " is not a valid form (APR_wwww form, wwww is hexadecimal value)");
-        }
-
         #if MEDIAINFO_ADVANCED
-        for (size_t k = 0; k < error_Type_Max; k++) {
-            if (!File_Adm_Private->Items[item_audioProgramme].Items[i].Errors[k].empty()) {
-                for (size_t j = 0; j < File_Adm_Private->Items[item_audioProgramme].Items[i].Errors[k].size(); j++) {
-                    Errors_Field[WarningError?Error:k].push_back("audioProgramme");
-                    Errors_Value[WarningError?Error:k].push_back(File_Adm_Private->Items[item_audioProgramme].Items[i].Errors[k][j]);
-                }
-            }
-        }
-
         //TODO: expand this proof of concept
         if (Config_AdmProfile.Ebu3392==1)
         {
@@ -1140,14 +1417,14 @@ void File_Adm::Streams_Fill()
         #endif // MEDIAINFO_ADVANCED
     }
 
-    FILL_START(audioContent, audioContentName, "Content")
+    FILL_START(audioContent, audioContentName)
         if (Full)
             FILL_A(audioContent, audioContentID, "ID");
         FILL_A(audioContent, audioContentName, "Title");
         FILL_E(audioContent, audioContentLabel, "Label");
         FILL_A(audioContent, audioContentLanguage, "Language");
         FILL_E(audioContent, dialogue, "Mode");
-        FILL_E(audioContent, integratedLoudness, "IntegratedLoudness");
+        FILL_E(audioContent, loudnessMetadata_integratedLoudness, "IntegratedLoudness");
         LINK(audioContent, "Object", audioObjectIDRef, audioObject);
         const Ztring& Label = Retrieve_Const(StreamKind_Last, StreamPos_Last, (P + " Label").c_str());
         if (!Label.empty()) {
@@ -1159,18 +1436,20 @@ void File_Adm::Streams_Fill()
         }
     }
 
-    FILL_START(audioObject, audioObjectName, "Object")
+    FILL_START(audioObject, audioObjectName)
         if (Full)
             FILL_A(audioObject, audioObjectID, "ID");
         FILL_A(audioObject, audioObjectName, "Title");
         FILL_A(audioObject, startTime, "Start");
         FILL_A(audioObject, duration, "Duration");
         LINK(audioObject, "PackFormat", audioPackFormatIDRef, audioPackFormat);
+        LINK(audioObject, "Object", audioObjectIDRef, audioObject);
+        LINK(audioObject, "ComplementaryObject", audioComplementaryObjectIDRef, audioObject);
         if (Full)
             LINK(audioObject, "TrackUID", audioTrackUIDRef, audioTrackUID);
     }
 
-    FILL_START(audioPackFormat, audioPackFormatName, "PackFormat")
+    FILL_START(audioPackFormat, audioPackFormatName)
         if (Full)
             FILL_A(audioPackFormat, audioPackFormatID, "ID");
         FILL_A(audioPackFormat, audioPackFormatName, "Title");
@@ -1201,7 +1480,7 @@ void File_Adm::Streams_Fill()
         LINK(audioPackFormat, "ChannelFormat", audioChannelFormatIDRef, audioChannelFormat);
     }
 
-    FILL_START(audioChannelFormat, audioChannelFormatName, "ChannelFormat")
+    FILL_START(audioChannelFormat, audioChannelFormatName)
         if (Full)
             FILL_A(audioChannelFormat, audioChannelFormatID, "ID");
         FILL_A(audioChannelFormat, audioChannelFormatName, "Title");
@@ -1212,7 +1491,7 @@ void File_Adm::Streams_Fill()
     }
 
     if (Full) {
-        FILL_START(audioTrackUID, UID, "TrackUID")
+        FILL_START(audioTrackUID, UID)
             FILL_A(audioTrackUID, UID, "ID");
             FILL_A(audioTrackUID, bitDepth, "BitDepth");
             FILL_A(audioTrackUID, sampleRate, "SamplingRate");
@@ -1235,7 +1514,7 @@ void File_Adm::Streams_Fill()
             LINK(audioTrackUID, "TrackFormat", audioTrackFormatIDRef, audioTrackFormat);
         }
 
-        FILL_START(audioTrackFormat, audioTrackFormatName, "TrackFormat")
+        FILL_START(audioTrackFormat, audioTrackFormatName)
             FILL_A(audioTrackFormat, audioTrackFormatID, "ID");
             FILL_A(audioTrackFormat, audioTrackFormatName, "Title");
             FILL_A(audioTrackFormat, formatDefinition, "FormatDefinition");
@@ -1243,7 +1522,7 @@ void File_Adm::Streams_Fill()
             LINK(audioTrackFormat, "StreamFormat", audioStreamFormatIDRef, audioStreamFormat);
         }
 
-        FILL_START(audioStreamFormat, audioStreamFormatName, "StreamFormat")
+        FILL_START(audioStreamFormat, audioStreamFormatName)
             FILL_A(audioStreamFormat, audioStreamFormatID, "ID");
             FILL_A(audioStreamFormat, audioStreamFormatName, "Title");
             FILL_A(audioStreamFormat, formatDefinition, "Format");
@@ -1257,23 +1536,51 @@ void File_Adm::Streams_Fill()
     if (!File_Adm_Private->Items[item_audioTrack].Items.empty())
     {
         Fill(Stream_Audio, 0, "Transport0", "Yes");
-        FILL_START(audioTrack, Summary, "Transport0 TrackIndex")
+        FILL_START_SUB(audioTrack, Summary, "Transport0 TrackIndex")
             FILL_E(audioTrack, audioTrackUIDRef, "");
             if (Full)
                 LINK(audioTrack, "TrackUID", audioTrackUIDRef, audioTrackUID);
         }
-
     }
 
     if (!Full)
         Fill(Stream_Audio, 0, "PartialDisplay", "Yes");
 
+    // Errors
     #if MEDIAINFO_ADVANCED
+    CheckErrors(File_Adm_Private);
+    for (size_t t = 0; t < item_Max; t++) {
+        for (size_t i = 0; i < File_Adm_Private->Items[t].Items.size(); i++) {
+            FillErrors(File_Adm_Private, (item)t, i, item_Info[t].Name, &Errors_Field[0], &Errors_Value[0], WarningError); \
+        }
+    }
+
+    //Conformance
     for (size_t k = 0; k < error_Type_Max; k++) {
         if (!Errors_Field[k].empty()) {
-            Fill(StreamKind_Last, StreamPos_Last, error_Type_String[k], Errors_Field[k].size());
+            auto FieldPrefix = "Conformance" + string(error_Type_String[k]);
+            Fill(StreamKind_Last, StreamPos_Last, FieldPrefix.c_str(), Errors_Field[k].size());
+            FieldPrefix += ' ';
             for (size_t i = 0; i < Errors_Field[k].size(); i++) {
-                Fill(StreamKind_Last, StreamPos_Last, (string(error_Type_String[k]) + ' ' + Errors_Field[k][i]).c_str(), Errors_Value[k][i]);
+                size_t Space = 0;
+                for (;;)
+                {
+                    Space = Errors_Field[k][i].find(' ', Space + 1);
+                    if (Space == string::npos) {
+                        break;
+                    }
+                    const auto Field = FieldPrefix + Errors_Field[k][i].substr(0, Space);
+                    const auto& Value = Retrieve_Const(StreamKind_Last, StreamPos_Last, Field.c_str());
+                    if (Value.empty()) {
+                        Fill(StreamKind_Last, StreamPos_Last, Field.c_str(), "Yes");
+                    }
+                }
+                const auto Field = FieldPrefix + Errors_Field[k][i];
+                const auto& Value = Retrieve_Const(StreamKind_Last, StreamPos_Last, Field.c_str());
+                if (Value == __T("Yes")) {
+                    Clear(StreamKind_Last, StreamPos_Last, Field.c_str());
+                }
+                Fill(StreamKind_Last, StreamPos_Last, Field.c_str(), Errors_Value[k][i]);
             }
         }
     }
