@@ -1316,6 +1316,8 @@ enum text
     Text_DisplayAspectRatio_Original_String,
     Text_FrameRate_Mode,
     Text_FrameRate_Mode_String,
+    Text_FrameRate_Mode_Original,
+    Text_FrameRate_Mode_Original_String,
     Text_FrameRate,
     Text_FrameRate_String,
     Text_FrameRate_Num,
@@ -1328,6 +1330,8 @@ enum text
     Text_FrameRate_Maximum_String,
     Text_FrameRate_Original,
     Text_FrameRate_Original_String,
+    Text_FrameRate_Original_Num,
+    Text_FrameRate_Original_Den,
     Text_FrameCount,
     Text_ElementCount,
     Text_Source_FrameCount,
@@ -1458,6 +1462,13 @@ enum text
     Text_Tagged_Date,
     Text_Encryption,
     Text_Events_Total,
+    Text_Events_MinDuration,
+    Text_Events_MinDuration_String,
+    Text_Events_MinDuration_String1,
+    Text_Events_MinDuration_String2,
+    Text_Events_MinDuration_String3,
+    Text_Events_MinDuration_String4,
+    Text_Events_MinDuration_String5,
     Text_Events_PopOn,
     Text_Events_RollUp,
     Text_Events_PaintOn,
@@ -1601,8 +1612,8 @@ enum other
     Other_TimeCode_LastFrame,
     Other_TimeCode_DropFrame,
     Other_TimeCode_Settings,
-    Other_TimeCode_Striped,
-    Other_TimeCode_Striped_String,
+    Other_TimeCode_Stripped,
+    Other_TimeCode_Stripped_String,
     Other_TimeCode_Source,
     Other_StreamSize,
     Other_StreamSize_String,
