@@ -34,8 +34,8 @@ using namespace ZenLib;
 using std::vector;
 using std::string;
 using std::map;
+using std::set;
 using std::make_pair;
-using namespace std;
 //---------------------------------------------------------------------------
 
 namespace MediaInfoLib
@@ -270,6 +270,8 @@ public :
     #if MEDIAINFO_ADVANCED && defined(MEDIAINFO_FILE_YES)
           void      TimeOut_Set (int64u Value);
           int64u    TimeOut_Get ();
+          void      AcceptSignals_Set (bool Value);
+          bool      AcceptSignals_Get ();
     #endif //MEDIAINFO_ADVANCED && defined(MEDIAINFO_FILE_YES)
 
           void      MpegTs_MaximumOffset_Set (int64u Value);
@@ -343,6 +345,25 @@ public :
         bool GraphSvgPluginState();
     #endif //defined(MEDIAINFO_GRAPH_YES)
 
+    #if MEDIAINFO_ADVANCED
+          Ztring    AdmProfile (const Ztring& Value);
+          struct adm_profile
+          {
+              bool Auto;
+              int BS2076;
+              int Ebu3392;
+
+              adm_profile() :
+                  Auto(false),
+                  BS2076(-1),
+                  Ebu3392(-1)
+              {}
+          };
+          adm_profile      AdmProfile();
+          void        WarningError(bool Value);
+          bool        WarningError();
+    #endif
+
     #if defined(MEDIAINFO_LIBCURL_YES)
           bool      CanHandleUrls();
           enum urlencode
@@ -393,6 +414,7 @@ private :
     #endif //MEDIAINFO_ADVANCED
     #if MEDIAINFO_ADVANCED && defined(MEDIAINFO_FILE_YES)
         int64u      TimeOut;
+        bool        AcceptSignals;
     #endif //MEDIAINFO_ADVANCED && defined(MEDIAINFO_FILE_YES)
 
     int64u          MpegTs_MaximumOffset;
@@ -491,6 +513,11 @@ private :
     void*           Event_UserHandler;
     #endif //MEDIAINFO_EVENTS
 
+    #if MEDIAINFO_ADVANCED
+    adm_profile Adm_Profile;
+    bool Warning_Error;
+    #endif
+
     #if defined(MEDIAINFO_LIBCURL_YES)
           urlencode URLEncode;
           Ztring    Ssh_PublicKeyFileName;
