@@ -162,6 +162,8 @@ public :
         bool          File_HighestFormat_Get ();
         void          File_ChannelLayout_Set(bool NewValue);
         bool          File_ChannelLayout_Get();
+        void          File_FrameIsAlwaysComplete_Set(bool NewValue) { File_FrameIsAlwaysComplete = NewValue; }
+        bool          File_FrameIsAlwaysComplete_Get() { return File_FrameIsAlwaysComplete; }
 #endif //MEDIAINFO_ADVANCED
 
     #if MEDIAINFO_DEMUX
@@ -350,8 +352,8 @@ public :
     bool          File_DvDif_Analysis_Get ();
     #endif //defined(MEDIAINFO_DVDIF_ANALYZE_YES)
     #if MEDIAINFO_MACROBLOCKS
-    void          File_Macroblocks_Parse_Set (bool NewValue);
-    bool          File_Macroblocks_Parse_Get ();
+    void          File_Macroblocks_Parse_Set (int NewValue);
+    int           File_Macroblocks_Parse_Get ();
     #endif //MEDIAINFO_MACROBLOCKS
     void          File_GrowingFile_Delay_Set(float64 Value);
     float64       File_GrowingFile_Delay_Get();
@@ -457,6 +459,7 @@ private :
         bool                File_MergeBitRateInfo;
         bool                File_HighestFormat;
         bool                File_ChannelLayout;
+        bool                File_FrameIsAlwaysComplete;
         #if MEDIAINFO_DEMUX
             bool                File_Demux_Unpacketize_StreamLayoutChange_Skip;
         #endif //MEDIAINFO_DEMUX
@@ -580,7 +583,7 @@ private :
     bool                    File_DvDif_Analysis;
     #endif //defined(MEDIAINFO_DVDIF_ANALYZE_YES)
     #if MEDIAINFO_MACROBLOCKS
-    bool                    File_Macroblocks_Parse;
+    int                     File_Macroblocks_Parse;
     #endif //MEDIAINFO_MACROBLOCKS
     float64                 File_GrowingFile_Delay;
     bool                    File_GrowingFile_Force;
