@@ -68,6 +68,9 @@
     #if !defined (MEDIAINFO_TRACE_NO) && !defined (MEDIAINFO_TRACE_YES)
         #define MEDIAINFO_TRACE_NO
     #endif
+    #if !defined (MEDIAINFO_CONFORMANCE_NO) && !defined (MEDIAINFO_CONFORMANCE_YES)
+        #define MEDIAINFO_CONFORMANCE_NO
+    #endif
     #if !defined (MEDIAINFO_FILTER_NO) && !defined (MEDIAINFO_FILTER_YES)
         #define MEDIAINFO_FILTER_NO
     #endif
@@ -248,6 +251,16 @@
         #define MEDIAINFO_ADVANCED2 0
     #endif
 #endif
+#if !defined(MEDIAINFO_CONFORMANCE)
+    #if defined(MEDIAINFO_CONFORMANCE_NO) && defined(MEDIAINFO_CONFORMANCE_YES)
+        #undef MEDIAINFO_CONFORMANCE_NO //MEDIAINFO_CONFORMANCE_YES has priority
+    #endif
+    #if defined(MEDIAINFO_CONFORMANCE_NO)
+        #define MEDIAINFO_CONFORMANCE 0
+    #else
+        #define MEDIAINFO_CONFORMANCE 1
+    #endif
+#endif
 #if !defined(MEDIAINFO_MD5)
     #if defined(MEDIAINFO_MD5_NO) && defined(MEDIAINFO_MD5_YES)
         #undef MEDIAINFO_MD5_NO //MEDIAINFO_MD5_YES has priority
@@ -548,6 +561,9 @@
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_MXF_NO) && !defined(MEDIAINFO_MXF_YES)
     #define MEDIAINFO_MXF_YES
 #endif
+#if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_NSV_NO) && !defined(MEDIAINFO_NSV_YES)
+    #define MEDIAINFO_NSV_YES
+#endif
 #if !defined(MEDIAINFO_MULTI_NO) && !defined(MEDIAINFO_NUT_NO) && !defined(MEDIAINFO_NUT_YES)
     #define MEDIAINFO_NUT_YES
 #endif
